@@ -18,17 +18,18 @@ class RequestCacheMiddleware(MiddlewareMixin):
 
     def process_response(self, request, response):
         """
-         Clear the request cache after processing a response.
-         """
+        Clear the request cache after processing a response.
+        """
+        # This is to just to do some basic cleanup, and isn't
+        # necessary for correctness; the next request will have the
+        # cache cleared during process_request anyhow.
+        #
+        # Note that clearing in process_exception would actually cause
+        # problems for other middleware that want to read the cache in
+        # their process_response.
         RequestCache.clear_all_namespaces()
         return response
 
-    def process_exception(self, request, exception):    # pylint: disable=W0613
-        """
-        Clear the request cache after a failed request.
-        """
-        RequestCache.clear_all_namespaces()
-
 
 class TieredCacheMiddleware(MiddlewareMixin):
     """
